import 'dart:ui';

import 'modules/common.dart';
import 'modules/application.dart';
import 'modules/state.dart';
import 'modules/homepage.dart';
import 'modules/remedical.dart';
import 'modules/route.dart';
import 'modules/setting.dart';
import 'modules/user.dart';

export 'modules/common.dart';
export 'modules/application.dart';
export 'modules/state.dart';
export 'modules/homepage.dart';
export 'modules/remedical.dart';
export 'modules/route.dart';
export 'modules/setting.dart';
export 'modules/user.dart';

abstract class IPropSearchable {
  /// 序列化
  Map<String, dynamic> toJson();

  /// 根据字段名获取
  dynamic getProp(String propName);
}

/// 翻译字典
///
/// [locale] 翻译语言
abstract class FLangKeyBook implements IPropSearchable {
  FLangKeyBook(this.locale);

  /// 本字典语言
  final Locale locale;

  /// 公共模块
  late final CommonModule common = buildCommonKeys();

  /// 首页模块
  late final HomePageModule homepage = buildHomePageKeys();

  /// 应用模块
  late final ApplicationModule app = buildApplicationKeys();

  /// 诊断模块
  late final RemedicalModule remedical = buildRemedicalKeys();

  /// 路由模块
  late final RouteModule route = buildRouteKeys();

  /// 设置模块
  late final SettingModule setting = buildSettingKeys();

  /// 平台模块
  late final StateModule state = buildStateKeys();

  /// 用户模块
  late final UserModule user = buildUserKeys();

  /// 构建公共模块字典
  CommonModule buildCommonKeys();

  /// 构建首页模块字典
  HomePageModule buildHomePageKeys();

  /// 构建应用模块字典
  ApplicationModule buildApplicationKeys();

  /// 构建诊断模块字典
  RemedicalModule buildRemedicalKeys();

  /// 构建路由模块字典
  RouteModule buildRouteKeys();

  /// 构建设置模块字典
  SettingModule buildSettingKeys();

  /// 构建状态模块字典
  StateModule buildStateKeys();

  /// 构建用户模块字典
  UserModule buildUserKeys();

  @override
  getProp(String propName) {
    if (propName == 'common') {
      return this.common;
    }
    throw ArgumentError('propery not found.');
  }

  @override
  Map<String, dynamic> toJson() {
    return {};
  }
}
